@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsound_panel.cpp,v 1.62.6.2 2012/08/28 16:55:35 cvs Exp $
+//      $Id: rdsound_panel.cpp,v 1.62.6.12 2014/02/06 20:43:47 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -318,43 +318,6 @@ void RDSoundPanel::setSvcName(const QString &svcname)
 }
 
 
-void RDSoundPanel::setButton(RDAirPlayConf::PanelType type,int panel,
-			   int row,int col,unsigned cartnum)
-{
-  QString str;
-
-  RDPanelButton *button=
-    panel_buttons[PanelOffset(type,panel)]->panelButton(row,col);
-  if(button->playDeck()!=NULL) {
-    return;
-  }
-  button->clear();
-  if(cartnum>0) {
-    button->setCart(cartnum);
-    RDCart *cart=new RDCart(cartnum);
-    if(cart->exists()) {
-      button->
-	setText(RDLogLine::resolveWildcards(cartnum,panel_label_template));
-      button->setLength(false,cart->forcedLength());
-      if(cart->averageHookLength()>0) {
-	button->setLength(true,cart->averageHookLength());
-      }
-      else {
-	button->setLength(true,cart->forcedLength());
-      }
-      button->setHookMode(panel_playmode_box->currentItem()==1);
-      button->setActiveLength(button->length(button->hookMode()));
-    }
-    else {
-      str=QString(tr("Cart"));
-      button->setText(QString().sprintf("%s %06u",(const char *)str,cartnum));
-    }
-    delete cart;
-  }
-  SaveButton(type,panel,row,col);
-}
-
-
 void RDSoundPanel::setLogfile(QString filename)
 {
   panel_logfile=filename;
@@ -389,6 +352,24 @@ void RDSoundPanel::stop(RDAirPlayConf::PanelType type,int panel,
 }
 
 
+void RDSoundPanel::channelStop(int mport)
+{
+  RDPanelButton *button=NULL;
+  RDPlayDeck *deck=NULL;
+  for(unsigned i=0;i<RD_MAX_STREAMS;i++) {
+    if((button=panel_active_buttons[i])!=NULL) {
+      if(button->outputText().toInt()==(mport+1)) {
+	if((deck=button->playDeck())!=NULL) {
+	  if(deck->state()==RDPlayDeck::Playing) {
+	    deck->stop();
+	  }
+	}
+      }
+    }
+  }
+}
+
+
 void RDSoundPanel::setText(RDAirPlayConf::PanelType type,int panel,int row,
 			   int col,const QString &str)
 {
@@ -516,6 +497,80 @@ RDAirPlayConf::PanelType RDSoundPanel::currentType() const
 }
 
 
+void RDSoundPanel::setButton(RDAirPlayConf::PanelType type,int panel,
+			     int row,int col,unsigned cartnum,
+			     const QString &title)
+{
+  QString str;
+
+  RDPanelButton *button=
+    panel_buttons[PanelOffset(type,panel)]->panelButton(row,col);
+  if(button->playDeck()!=NULL) {
+    return;
+  }
+  button->clear();
+  if(cartnum>0) {
+    button->setCart(cartnum);
+    RDCart *cart=new RDCart(cartnum);
+    if(cart->exists()) {
+      if(title.isEmpty()) {
+	button->
+	  setText(RDLogLine::resolveWildcards(cartnum,panel_label_template));
+      }
+      else {
+	button->setText(title);
+      }
+      button->setLength(false,cart->forcedLength());
+      if(cart->averageHookLength()>0) {
+	button->setLength(true,cart->averageHookLength());
+      }
+      else {
+	button->setLength(true,cart->forcedLength());
+      }
+      button->setHookMode(panel_playmode_box->currentItem()==1);
+      switch(cart->type()) {
+      case RDCart::Audio:
+	if(button->length(button->hookMode())==0) {
+	  button->setActiveLength(-1);
+	}
+	else {
+	  button->setActiveLength(button->length(button->hookMode()));
+	}
+	break;
+
+      case RDCart::Macro:
+	button->setActiveLength(cart->forcedLength());
+	break;
+
+      case RDCart::All:
+	break;
+      }
+    }
+    else {
+      if(title.isEmpty()) {
+	str=QString(tr("Cart"));
+	button->setText(QString().sprintf("%s %06u",(const char *)str,cartnum));
+      }
+      else {
+	button->setText(title);
+      }
+    }
+    delete cart;
+  }
+  SaveButton(type,panel,row,col);
+}
+
+
+void RDSoundPanel::acceptCartDrop(int row,int col,unsigned cartnum,
+				  const QColor &color,const QString &title)
+{
+  setButton(panel_type,panel_number,row,col,cartnum,title);
+  if(color.isValid()&&(color.name()!="#000000")) {
+    setColor(panel_type,panel_number,row,col,color);
+  }
+}
+
+
 void RDSoundPanel::changeUser()
 {
   if(panel_user!=NULL) {
@@ -633,6 +688,13 @@ void RDSoundPanel::setupClickedData()
     panel_reset_button->setDisabled(true);
     panel_playmode_box->setDisabled(true);
   }
+  if(panel_station->enableDragdrop()&&(panel_station->enforcePanelSetup())) {
+    for(unsigned i=0;i<panel_buttons.size();i++) {
+      if(panel_buttons[i]!=NULL) {
+	panel_buttons[i]->setAcceptDrops(panel_setup_mode);
+      }
+    }
+  }
   panel_selector_box->setSetupMode(panel_setup_mode);
 }
 
@@ -687,7 +749,8 @@ void RDSoundPanel::buttonMapperData(int id)
 	  }
 	  if(panel_button_dialog->
 	     exec(panel_buttons[PanelOffset(panel_type,panel_number)]->
-		  panelButton(row,col),panel_playmode_box->currentItem()==1)
+		  panelButton(row,col),panel_playmode_box->currentItem()==1,
+		  panel_user->name(),panel_user->password())
 	     ==0) {
 	    SaveButton(panel_type,panel_number,row,col);
 	  }
@@ -985,6 +1048,8 @@ bool RDSoundPanel::PlayAudio(RDPanelButton *button,RDCart *cart,bool hookmode,in
   button->playDeck()->play(start_pos,segue_start,segue_end);
   panel_event_player->
     exec(logline.resolveWildcards(panel_start_rml[button->output()]));
+  emit channelStarted(button->output(),button->playDeck()->card(),
+		      button->playDeck()->port());
   return true;
 }
 
@@ -1127,7 +1192,7 @@ void RDSoundPanel::LoadPanels()
   // Load Buttons
   //
   for(int i=0;i<panel_station_panels;i++) {
-    panel_buttons.push_back(new RDButtonPanel(panel_button_columns,
+    panel_buttons.push_back(new RDButtonPanel(panel_type,i,panel_button_columns,
 					      panel_button_rows,
 					      panel_station,panel_flash,this));
     for(int j=0;j<panel_button_rows;j++) {
@@ -1139,9 +1204,10 @@ void RDSoundPanel::LoadPanels()
       }
     }
     LoadPanel(RDAirPlayConf::StationPanel,i);
+    panel_buttons.back()->setAllowDrags(panel_station->enableDragdrop());
   }
   for(int i=0;i<panel_user_panels;i++) {
-    panel_buttons.push_back(new RDButtonPanel(panel_button_columns,
+    panel_buttons.push_back(new RDButtonPanel(panel_type,i,panel_button_columns,
 					      panel_button_rows,
 					      panel_station,panel_flash,this));
     for(int j=0;j<panel_button_rows;j++) {
@@ -1152,6 +1218,7 @@ void RDSoundPanel::LoadPanels()
 			   j*panel_button_columns+k);
       }
     }
+    panel_buttons.back()->setAllowDrags(panel_station->enableDragdrop());
     LoadPanel(RDAirPlayConf::UserPanel,i);
   }
 }
@@ -1179,7 +1246,7 @@ void RDSoundPanel::LoadPanel(RDAirPlayConf::PanelType type,int panel)
 
   QString sql=QString().sprintf("select %s.ROW_NO,%s.COLUMN_NO,\
     %s.LABEL,%s.CART,%s.DEFAULT_COLOR,CART.FORCED_LENGTH,\
-    CART.AVERAGE_HOOK_LENGTH \
+    CART.AVERAGE_HOOK_LENGTH,CART.TYPE \
     from %s left join CART on %s.CART=CART.NUMBER\
     where %s.TYPE=%d && %s.OWNER=\"%s\" && %s.PANEL_NO=%d\
     order by %s.COLUMN_NO,%s.ROW_NO",
@@ -1221,9 +1288,23 @@ void RDSoundPanel::LoadPanel(RDAirPlayConf::PanelType type,int panel)
 	  setActiveLength(q->value(6).toInt());
       }
       else {
-	panel_buttons[offset]->
-	  panelButton(q->value(0).toInt(),q->value(1).toInt())->
-	  setActiveLength(q->value(5).toInt());
+	if(q->value(7).toInt()==RDCart::Macro) {
+	  panel_buttons[offset]->
+	    panelButton(q->value(0).toInt(),q->value(1).toInt())->
+	    setActiveLength(q->value(5).toInt());
+	}
+	else {
+	  if(q->value(5).toInt()>0) {
+	    panel_buttons[offset]->
+	      panelButton(q->value(0).toInt(),q->value(1).toInt())->
+	      setActiveLength(q->value(5).toInt());
+	  }
+	  else {
+	    panel_buttons[offset]->
+	      panelButton(q->value(0).toInt(),q->value(1).toInt())->
+	      setActiveLength(-1);
+	  }
+	}
       }
       if(q->value(4).toString().isEmpty()) {
 	panel_buttons[offset]->
@@ -1591,6 +1672,8 @@ void RDSoundPanel::ClearChannel(int id)
     return;
   }
   panel_event_player->exec(panel_stop_rml[panel_active_buttons[id]->output()]);
+  emit channelStopped(panel_active_buttons[id]->output(),
+		      playdeck->card(),playdeck->port());
 }
 
 
