@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: add_group.cpp,v 1.18 2007/10/04 20:53:28 dmills Exp $
+//      $Id: add_group.cpp,v 1.20 2010/07/29 19:32:34 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -37,7 +37,7 @@
 #include <add_group.h>
 #include <rdpasswd.h>
 #include <rdtextvalidator.h>
-
+#include <rdescape_string.h>
 
 AddGroup::AddGroup(QString *group,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
@@ -156,7 +156,7 @@ void AddGroup::okData()
   }
 
   sql=QString().sprintf("insert into GROUPS set NAME=\"%s\"",
-			(const char *)group_name_edit->text());
+			(const char *)RDEscapeString(group_name_edit->text()));
 
   q=new RDSqlQuery(sql);
   if(!q->isActive()) {
@@ -177,7 +177,7 @@ void AddGroup::okData()
       sql=QString().sprintf("insert into USER_PERMS set USER_NAME=\"%s\",\
                              GROUP_NAME=\"%s\"",
 			    (const char *)q->value(0).toString(),
-			    (const char *)group_name_edit->text());
+			    (const char *)RDEscapeString(group_name_edit->text()));
       q1=new RDSqlQuery(sql);
       delete q1;
     }
@@ -194,7 +194,7 @@ void AddGroup::okData()
       sql=QString().sprintf("insert into AUDIO_PERMS set SERVICE_NAME=\"%s\",\
                              GROUP_NAME=\"%s\"",
 			    (const char *)q->value(0).toString(),
-			    (const char *)group_name_edit->text());
+			    (const char *)RDEscapeString(group_name_edit->text()));
       q1=new RDSqlQuery(sql);
       delete q1;
     }
@@ -204,15 +204,15 @@ void AddGroup::okData()
   EditGroup *group=new EditGroup(group_name_edit->text(),this,"group");
   if(group->exec()<0) {
     sql=QString().sprintf("delete from USER_PERMS where GROUP_NAME=\"%s\"",
-			  (const char *)group_name_edit->text());
+			  (const char *)RDEscapeString(group_name_edit->text()));
     q=new RDSqlQuery(sql);
     delete q;
     sql=QString().sprintf("delete from AUDIO_PERMS where GROUP_NAME=\"%s\"",
-			  (const char *)group_name_edit->text());
+			  (const char *)RDEscapeString(group_name_edit->text()));
     q=new RDSqlQuery(sql);
     delete q;
     sql=QString().sprintf("delete from GROUPS where NAME=\"%s\"",
-			  (const char *)group_name_edit->text());
+			  (const char *)RDEscapeString(group_name_edit->text()));
     q=new RDSqlQuery(sql);
     delete q;
     delete group;
