@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: import_listview.cpp,v 1.18 2008/04/02 16:47:28 fredg Exp $
+//      $Id: import_listview.cpp,v 1.21.8.2 2013/12/30 19:56:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,6 +27,7 @@
 
 #include <rdcart.h>
 #include <rdconf.h>
+#include <rdcartdrag.h>
 
 #include <edit_note.h>
 #include <edit_track.h>
@@ -120,6 +121,7 @@ void ImportListView::refreshList(int line)
   QListViewItem *select_item=NULL;
   QString sql;
   RDLogLine *logline;
+  int total_len=0;
 
   clear();
   for(int i=import_log->size()-1;i>=0;i--) {
@@ -156,6 +158,7 @@ void ImportListView::refreshList(int line)
 	    break;
       }
       item->setText(3,RDGetTimeLength(logline->forcedLength(),false,false));
+      total_len+=logline->forcedLength();
       switch(logline->transType()) {
 	  case RDLogLine::Play:
 	    item->setText(5,tr("PLAY"));
@@ -182,6 +185,7 @@ void ImportListView::refreshList(int line)
     setSelected(select_item,true);
     ensureItemVisible(select_item);
   }
+  emit lengthChanged(total_len);
 }
 
 
@@ -447,28 +451,36 @@ void ImportListView::focusOutEvent(QFocusEvent *e)
 
 void ImportListView::dragEnterEvent(QDragEnterEvent *e)
 {
-  e->accept(QTextDrag::canDecode(e));
+  e->accept(RDCartDrag::canDecode(e));
 }
 
 
 void ImportListView::dropEvent(QDropEvent *e)
 {
   QListViewItem *item;
-  QString cartstr;
+  unsigned cartnum;
   int line=0;
   QPoint pos(e->pos().x(),e->pos().y()-header()->sectionRect(0).height());
 
-  if(QTextDrag::decode(e,cartstr)) {
-    if((item=itemAt(pos))==NULL) {
-	line=childCount();
+  if(RDCartDrag::decode(e,&cartnum)) {
+    if(cartnum==0) {
+      if((item=itemAt(pos))==NULL) {
+	return;
+      }
+      import_log->remove(item->text(6).toInt(),1);
     }
     else {
-      line=item->text(6).toInt();
+      if((item=itemAt(pos))==NULL) {
+	line=childCount();
+      }
+      else {
+	line=item->text(6).toInt();
+      }
+      import_log->insert(line,1);
+      import_log->logLine(line)->
+	loadCart(cartnum,RDLogLine::Segue,0,false);
+      import_log->logLine(line)->setTransType(RDLogLine::Segue);
     }
-    import_log->insert(line,1);
-    import_log->logLine(line)->
-      loadCart(cartstr.toUInt(),RDLogLine::Segue,0,false);
-    import_log->logLine(line)->setTransType(RDLogLine::Segue);
   }
   validateTransitions();
   refreshList(line);
