@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: bt16x2.cpp,v 1.7 2007/11/09 18:51:19 fredg Exp $
+//      $Id: bt16x2.cpp,v 1.14 2010/08/03 23:39:25 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,7 +29,7 @@
 
 
 Bt16x2::Bt16x2(RDMatrix *matrix,QObject *parent,const char *name)
-  : QObject(parent,name)
+  : Switcher(matrix,parent,name)
 {
   //
   // Initialize Data Structures
@@ -37,6 +37,7 @@ Bt16x2::Bt16x2(RDMatrix *matrix,QObject *parent,const char *name)
   bt_istate=0;
   for(int i=0;i<BT16X2_GPIO_PINS;i++) {
     bt_gpi_state[i]=false;
+    bt_gpi_mask[i]=false;
   }
 
   //
@@ -62,6 +63,16 @@ Bt16x2::Bt16x2(RDMatrix *matrix,QObject *parent,const char *name)
   }
   delete tty;
 
+  //
+  // Interval OneShots
+  //
+  bt_gpi_oneshot=new RDOneShot(this);
+  connect(bt_gpi_oneshot,SIGNAL(timeout(void *)),
+	  this,SLOT(gpiOneshotData(void*)));
+  bt_gpo_oneshot=new RDOneShot(this);
+  connect(bt_gpo_oneshot,SIGNAL(timeout(void *)),
+	  this,SLOT(gpoOneshotData(void*)));
+
   //
   // The Poll Timer
   //
@@ -74,6 +85,38 @@ Bt16x2::Bt16x2(RDMatrix *matrix,QObject *parent,const char *name)
 Bt16x2::~Bt16x2()
 {
   delete bt_device;
+  delete bt_gpi_oneshot;
+  delete bt_gpo_oneshot;
+}
+
+
+RDMatrix::Type Bt16x2::type()
+{
+  return RDMatrix::Bt16x2;
+}
+
+
+unsigned Bt16x2::gpiQuantity()
+{
+  return bt_gpis;
+}
+
+
+unsigned Bt16x2::gpoQuantity()
+{
+  return bt_gpos;
+}
+
+
+bool Bt16x2::primaryTtyActive()
+{
+  return true;
+}
+
+
+bool Bt16x2::secondaryTtyActive()
+{
+  return false;
 }
 
 
@@ -83,19 +126,34 @@ void Bt16x2::processCommand(RDMacro *cmd)
 
   switch(cmd->command()) {
       case RDMacro::GO:
-	if((cmd->argQuantity()!=4)||
-	   (cmd->arg(1).toInt()<1)||(cmd->arg(1).toInt()>bt_gpos)||
-	   (cmd->arg(1).toInt()>bt_gpos)||
-	   ((cmd->arg(2).toInt()!=1)&&(cmd->arg(2).toInt()!=0))||
-	   (cmd->arg(3).toInt()<0)) {
+	if((cmd->argQuantity()!=5)||
+	   ((cmd->arg(1).toString().lower()!="i")&&
+	    (cmd->arg(1).toString().lower()!="o"))||
+	   (cmd->arg(2).toInt()<1)||(cmd->arg(3).toInt()>bt_gpos)||
+	   (cmd->arg(2).toInt()>bt_gpos)||
+	   ((cmd->arg(3).toInt()!=1)&&(cmd->arg(3).toInt()!=0)&&
+	    (cmd->arg(1).toString().lower()!="i"))||
+	   ((cmd->arg(3).toInt()!=1)&&(cmd->arg(3).toInt()!=0)&&
+	    (cmd->arg(3).toInt()!=-1)&&(cmd->arg(1).toString().lower()=="i"))||
+	   (cmd->arg(4).toInt()<0)) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
 	  return;
 	}
-	if(cmd->arg(2).toInt()==0) {
-	  if(cmd->arg(3).toInt()==0) {
-	    sprintf(str,"*%dOR%02dF",BT16X2_UNIT_ID,cmd->arg(1).toInt());
-	    bt_device->writeBlock(str,7);
+	if(cmd->arg(3).toInt()==0) {  // Turn OFF
+	  if(cmd->arg(4).toInt()==0) {
+	    if(cmd->arg(1).toString().lower()=="i") {
+	      if(bt_gpi_state[cmd->arg(2).toInt()-1]) {
+		emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,false);
+		bt_gpi_state[cmd->arg(2).toInt()-1]=false;
+	      }
+	      bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
+	    }
+	    if(cmd->arg(1).toString().lower()=="o") {
+	      sprintf(str,"*%dOR%02dF",BT16X2_UNIT_ID,cmd->arg(2).toInt());
+	      bt_device->writeBlock(str,6);
+	      emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,false);
+	    }
 	  }
 	  else {
 	    if(cmd->echoRequested()) {
@@ -106,13 +164,41 @@ void Bt16x2::processCommand(RDMacro *cmd)
 	  }
 	}
 	else {
-	  if(cmd->arg(3).toInt()==0) {
-	    sprintf(str,"*%dOR%02dL",BT16X2_UNIT_ID,cmd->arg(1).toInt());
-	    bt_device->writeBlock(str,7);
+	  if(cmd->arg(3).toInt()==-1) {  // Clear input
+	    bt_gpi_mask[cmd->arg(2).toInt()-1]=false;
+	    bt_device->writeBlock("*0SPA",5);
 	  }
-	  else {
-	    sprintf(str,"*%dOR%02dP",BT16X2_UNIT_ID,cmd->arg(1).toInt());
-	    bt_device->writeBlock(str,7);
+	  else { 
+	    if(cmd->arg(4).toInt()==0) {  // Turn ON
+	      if(cmd->arg(1).toString().lower()=="i") {
+		if(!bt_gpi_state[cmd->arg(2).toInt()-1]) {
+		  emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
+		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
+		}
+		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
+	      }
+	      if(cmd->arg(1).toString().lower()=="o") {
+		sprintf(str,"*%dOR%02dL",BT16X2_UNIT_ID,cmd->arg(2).toInt());
+		bt_device->writeBlock(str,6);
+		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
+	      }
+	    }
+	    else {  // Pulse
+	      if(cmd->arg(1).toString().lower()=="i") {
+		if(!bt_gpi_state[cmd->arg(2).toInt()-1]) {
+		  emit gpiChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
+		  bt_gpi_state[cmd->arg(2).toInt()-1]=true;
+		}
+		bt_gpi_mask[cmd->arg(2).toInt()-1]=true;
+		bt_gpi_oneshot->start((void *)(cmd->arg(2).toInt()-1),500);
+	      }
+	      if(cmd->arg(1).toString().lower()=="o") {
+		sprintf(str,"*%dOR%02dP",BT16X2_UNIT_ID,cmd->arg(2).toInt());
+		bt_device->writeBlock(str,6);
+		emit gpoChanged(bt_matrix,cmd->arg(2).toInt()-1,true);
+		bt_gpo_oneshot->start((void *)(cmd->arg(2).toInt()-1),500);
+	      }
+	    }
 	  }
 	}
 	if(cmd->echoRequested()) {
@@ -242,7 +328,7 @@ void Bt16x2::processStatus()
 	  case 36:
 	    if(buffer[i]=='0') {
 	      gpi=(bt_istate-6)/2;
-	      if(bt_gpi_state[gpi]) {
+	      if(bt_gpi_state[gpi]&&(!bt_gpi_mask[gpi])) {
 		emit gpiChanged(bt_matrix,gpi,false);
 		bt_gpi_state[gpi]=false;
 	      }
@@ -250,7 +336,7 @@ void Bt16x2::processStatus()
 	    }
 	    if(buffer[i]=='1') {
 	      gpi=(bt_istate-6)/2;
-	      if(!bt_gpi_state[gpi]) {
+	      if((!bt_gpi_state[gpi])&&(!bt_gpi_mask[gpi])) {
 		emit gpiChanged(bt_matrix,gpi,true);
 		bt_gpi_state[gpi]=true;
 	      }
@@ -264,3 +350,16 @@ void Bt16x2::processStatus()
     }
   }
 }
+
+
+void Bt16x2::gpiOneshotData(void *data)
+{
+  bt_gpi_mask[(long)data]=false;
+  bt_device->writeBlock("*0SPA",5);
+}
+
+
+void Bt16x2::gpoOneshotData(void *data)
+{
+  emit gpoChanged(bt_matrix,(long)data,false);
+}
