@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsoftkeys.cpp,v 1.7.8.1 2013/01/07 15:35:08 cvs Exp $
+//      $Id: rdsoftkeys.cpp,v 1.7.8.2 2014/01/08 02:08:41 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,6 +30,7 @@
 
 #include <qtranslator.h>
 #include <qapplication.h>
+#include <qwindowsstyle.h>
 #include <qtextcodec.h>
 #include <qsignalmapper.h>
 #include <qpushbutton.h>
@@ -284,6 +285,7 @@ QString MainWidget::WrapText(QWidget *w,const QString &text)
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv);
+  QApplication::setStyle(new QWindowsStyle);
   
   //
   // Load Translations
